package com.gic.cloud.data.hook.web;

import com.gic.cloud.data.hook.api.dto.FreeQuerySource;
import com.gic.cloud.data.hook.api.service.IFreeQueryService;
import com.gic.enterprise.api.dto.EnterpriseDTO;
import com.gic.enterprise.api.service.EnterpriseService;
import com.gic.web.common.utils.SessionContextUtils;
import com.lmax.disruptor.util.DaemonThreadFactory;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Controller
public class AlarmController {
    private static final Logger log = LogManager.getLogger(AlarmController.class);

    @Autowired
    private EnterpriseService enterpriseService;
    @Autowired
    private IFreeQueryService freeQueryService;

    @RequestMapping("service-alarm")
    public Map<String, Object> serviceAlarm(){
        EnterpriseDTO enterprise = this.enterpriseService.getEnterpriseById(SessionContextUtils.getLoginUserEnterpriseId());
        Integer alarmWay = enterprise.getAlarmWay();
        Date expireTime = enterprise.getDatahookEndDate();
        return this.getAlarmResult(expireTime, alarmWay);
    }

    @RequestMapping("custom-alarm")
    public Map<String, Object> customAlarm(){
        EnterpriseDTO enterprise = this.enterpriseService.getEnterpriseById(SessionContextUtils.getLoginUserEnterpriseId());
        Integer alarmWay = enterprise.getAlarmWay();
        FreeQuerySource freeQuerySource = this.freeQueryService.getFreeQuerySource(SessionContextUtils.getLoginUserEnterpriseId());
        Date expireTime = freeQuerySource.getDbExpiration();
        Map<String, Object> alarmResult = this.getAlarmResult(expireTime, alarmWay);
        alarmResult.put("isPrivate", freeQuerySource.getIsPrivate());
        return alarmResult;
    }

    private Map<String, Object> getAlarmResult(Date expireTime, Integer alarmWay){
        Map<String, Object> result = new HashMap<>();
        if(expireTime != null){
            if(expireTime.before(new Date())){
                result.put("type", 2);
                result.put("remain", 0);
            }else {
                Date alarmTime = null;
                Calendar calendar = Calendar.getInstance();
                if(alarmWay == 1){
                    calendar.setTime(expireTime);
                    calendar.add(Calendar.MONTH, -2);
                }else if(alarmWay == 2){
                    calendar.setTime(expireTime);
                    calendar.add(Calendar.MONTH, -1);
                }else {
                    calendar.setTime(expireTime);
                    calendar.add(Calendar.DATE, -7);
                }
                alarmTime = calendar.getTime();
                if(alarmTime.before(new Date())){
                    result.put("type", 1);
                    result.put("remain", getDays(expireTime));
                }else {
                    result.put("type", 0);
                    result.put("remain", 0);
                }
            }
        }else {
            result.put("type", 0);
            result.put("remain", 0);
        }
        return result;
    }

    private long getDays(Date expireTime){
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
        try {
            Date date = dateFormat.parse(dateFormat.format(expireTime));
            Date now = dateFormat.parse(dateFormat.format(new Date()));
            long l = (date.getTime() - now.getTime()) / 3600 / 24 / 1000;
            return l;
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return 0;
    }
}
